# CAMELS library

**CAMELS** stands for **C**osmology and **A**strophysics with **M**achin**E** **L**earning **S**imulations. It is a set of thousands of cosmological N-body and state-of-the-art hydrodynamic simulations run with different codes. The simulations of the CAMELS project are described in detail in the [2010.00619](https://arxiv.org/abs/2010.00619).

This repository contains the codes and scripts used to analyze the data from the CAMELS simulations.

## Installation

For the stable version do:

``` sh
python -m pip install camels_library
```

For the development version do

```sh 
git clone https://github.com/franciscovillaescusa/CAMELS
cd CAMELS
python -m pip install .
```

## Documentation 

Click [here](https://camels.readthedocs.io) for the detailed documentation. 


## Contact

For questions, comments...etc, please reach us at camel.simulations@gmail.com

